@@ -17,12 +17,14 @@
 """ACL Generator base class."""
 
 import copy
-import logging
+import datetime
+import hashlib
 import re
 import string
 
+from absl import logging
+
 from aerleon.lib import policy
-import hashlib
 
 
 # generic error class
@@ -294,53 +296,50 @@ class ACLGenerator:
         """Initialise an ACLGenerator.  Store policy structure for processing."""
         supported_tokens, supported_sub_tokens = self._GetSupportedTokens()
 
+        pol.filters[:] = [
+            (header, terms)
+            for (header, terms) in pol.filters
+            if (self._PLATFORM in header.platforms)
+        ]
         self.policy = pol
         all_err = []
         all_warn = []
         for header, terms in pol.filters:
-            if self._PLATFORM in header.platforms:
-                # Verify valid keywords
-                # error on unsupported optional keywords that could result
-                # in dangerous or unexpected results
-                for term in terms:
-                    if term.platform:
-                        if self._PLATFORM not in term.platform:
-                            continue
-                    if term.platform_exclude:
-                        if self._PLATFORM in term.platform_exclude:
-                            continue
-                    # Only verify optional keywords if the term is active on the platform.
-                    err = []
-                    warn = []
-                    for el, val in term.__dict__.items():
-                        # Private attributes do not need to be valid keywords.
-                        if val and el not in supported_tokens and not el.startswith('flatten'):
-                            if val and el not in self.WARN_IF_UNSUPPORTED:
-                                err.append(el)
-                            else:
-                                warn.append(el)
-                        # ignore Liskov's rule.
-                        if val and isinstance(val, list) and el in supported_sub_tokens:
-                            ns = set(val) - supported_sub_tokens[el]
-                            # hack support for ArbitraryOptions in junos. todo, add the
-                            # junos options into the lexer, then we can nuke .*
-                            # shenanigans.
-                            if ns and '.*' not in supported_sub_tokens[el]:
-                                err.append(' '.join(ns))
-                    if err:
-                        all_err.append(
-                            ('%s contains unsupported keywords (%s) for target ' '%s in policy %s')
-                            % (term.name, ' '.join(err), self._PLATFORM, pol.filename)
-                        )
-                    if warn:
-                        all_warn.append(
-                            (
-                                '%s contains unimplemented keywords (%s) for '
-                                'target %s in policy %s'
-                            )
-                            % (term.name, ' '.join(warn), self._PLATFORM, pol.filename)
-                        )
-                continue
+            terms[:] = self._FilteredTerms(header, terms, exp_info)
+
+            # Verify valid keywords
+            # error on unsupported optional keywords that could result
+            # in dangerous or unexpected results
+            for term in terms:
+                # Only verify optional keywords if the term is active on the platform.
+                err = []
+                warn = []
+                for el, val in term.__dict__.items():
+                    # Private attributes do not need to be valid keywords.
+                    if val and el not in supported_tokens and not el.startswith('flatten'):
+                        if val and el not in self.WARN_IF_UNSUPPORTED:
+                            err.append(el)
+                        else:
+                            warn.append(el)
+                    # ignore Liskov's rule.
+                    if val and isinstance(val, list) and el in supported_sub_tokens:
+                        ns = set(val) - supported_sub_tokens[el]
+                        # hack support for ArbitraryOptions in junos. todo, add the
+                        # junos options into the lexer, then we can nuke .*
+                        # shenanigans.
+                        if ns and '.*' not in supported_sub_tokens[el]:
+                            err.append(' '.join(ns))
+                if err:
+                    all_err.append(
+                        ('%s contains unsupported keywords (%s) for target %s in policy %s')
+                        % (term.name, ' '.join(err), self._PLATFORM, pol.filename)
+                    )
+                if warn:
+                    all_warn.append(
+                        ('%s contains unimplemented keywords (%s) for target %s in policy %s')
+                        % (term.name, ' '.join(warn), self._PLATFORM, pol.filename)
+                    )
+            continue
         if all_err:
             raise UnsupportedFilterError('\n %s' % '\n'.join(all_err))
         if all_warn:
@@ -540,6 +539,37 @@ class ACLGenerator:
         name_bytes = name.encode('UTF-8')
         return hashlib.sha256(name_bytes).hexdigest()[:truncation_length]
 
+    def _FilteredTerms(self, header, terms, exp_info):
+        new_terms = []
+        filter_name = header.FilterName(self._PLATFORM)
+        current_date = datetime.datetime.utcnow().date()
+        exp_info_date = current_date + datetime.timedelta(weeks=exp_info)
+
+        for term in terms:
+            if term.expiration:
+                if term.expiration <= current_date:
+                    logging.warning(
+                        'WARNING: Term %s in policy %s is expired and will not be rendered.',
+                        term.name,
+                        filter_name,
+                    )
+                    continue
+                elif term.expiration <= exp_info_date:
+                    logging.info(
+                        "INFO: Term %s in policy %s expires in less than two weeks.",
+                        term.name,
+                        filter_name,
+                    )
+
+            if (term.platform and self._PLATFORM not in term.platform) or (
+                term.platform_exclude and self._PLATFORM in term.platform_exclude
+            ):
+                continue
+
+            new_terms.append(term)
+
+        return new_terms
+
 
 def ProtocolNameToNumber(protocols, proto_to_num, name_to_num_map):
     """Convert a protocol name to a numeric value.
