@@ -16,10 +16,10 @@
 """arista traffic-policy generator."""
 
 import copy
-import datetime
 import re
 
 from absl import logging
+
 from aerleon.lib import aclgenerator
 
 #          1         2         3
@@ -157,13 +157,6 @@ class Term(aclgenerator.Term):
             raise ValueError("unknown filter type: %s" % term_type)
 
     def __str__(self):
-        # verify platform specific terms. skip the whole term if the platform
-        # does not match.
-        if self.term.platform and self._PLATFORM not in self.term.platform:
-            return ""
-        if self.term.platform_exclude and self._PLATFORM in self.term.platform_exclude:
-            return ""
-
         config = Config()
 
         # a LoL which will be appended to the config at the end of this method
@@ -243,7 +236,7 @@ class Term(aclgenerator.Term):
         if not has_match_criteria and not is_default_term:
             # this term doesn't match on anything and isn't a default-term
             logging.warning(
-                "WARNING: term %s has no valid match criteria and " "will not be rendered.",
+                "WARNING: term %s has no valid match criteria and will not be rendered.",
                 self.term.name,
             )
             return ""
@@ -717,13 +710,7 @@ class AristaTrafficPolicy(aclgenerator.ACLGenerator):
         self.arista_traffic_policies = []
         af_map_txt = {"inet": "ipv4", "inet6": "ipv6"}
 
-        current_date = datetime.datetime.utcnow().date()
-        exp_info_date = current_date + datetime.timedelta(weeks=exp_info)
-
         for header, terms in pol.filters:
-            if self._PLATFORM not in header.platforms:
-                continue
-
             filter_options = header.FilterOptions(self._PLATFORM)
             filter_name = header.FilterName(self._PLATFORM)
             noverbose = "noverbose" in filter_options[1:]
@@ -780,22 +767,6 @@ class AristaTrafficPolicy(aclgenerator.ACLGenerator):
                     if not term:
                         continue
 
-                    if term.expiration:
-                        if term.expiration <= exp_info_date:
-                            logging.info(
-                                "INFO: term %s in policy %s expires " "in less than two weeks.",
-                                term.name,
-                                filter_name,
-                            )
-                        if term.expiration <= current_date:
-                            logging.warning(
-                                "WARNING: term %s in policy %s is expired and "
-                                "will not be rendered.",
-                                term.name,
-                                filter_name,
-                            )
-                            continue
-
                     # emit warnings for unsupported options / terms
                     if term.option:
                         unsupported_opts = []
@@ -923,7 +894,14 @@ class AristaTrafficPolicy(aclgenerator.ACLGenerator):
                     new_terms.append(self._TERM(term, ft, noverbose))
 
             self.arista_traffic_policies.append(
-                (header, filter_name, filter_type, new_terms, sorted(policy_counters), policy_field_sets)
+                (
+                    header,
+                    filter_name,
+                    filter_type,
+                    new_terms,
+                    sorted(policy_counters),
+                    policy_field_sets,
+                )
             )
 
     def __str__(self):
