@@ -16,16 +16,12 @@
 
 """Cisco generator."""
 
-import datetime
 import ipaddress
-from typing import cast, Union
+from typing import Union, cast
 
 from absl import logging
-from aerleon.lib import addressbook
-from aerleon.lib import aclgenerator
-from aerleon.lib import nacaddr
-from aerleon.lib import summarizer
 
+from aerleon.lib import aclgenerator, addressbook, nacaddr, summarizer
 
 _ACTION_TABLE = {
     'accept': 'permit',
@@ -110,15 +106,6 @@ class TermStandard:
             self.dscpstring = ' dscp' + self.term.dscp_match
 
     def __str__(self):
-        # Verify platform specific terms. Skip whole term if platform does not
-        # match.
-        if self.term.platform:
-            if self.platform not in self.term.platform:
-                return ''
-        if self.term.platform_exclude:
-            if self.platform in self.term.platform_exclude:
-                return ''
-
         ret_str = []
 
         # Term verbatim output - this will skip over normal term creation
@@ -254,16 +241,16 @@ class ObjectGroup:
         netgroups = set()
         ports = {}
 
-            # I don't have an easy way get the token name used in the pol file
-            # w/o reading the pol file twice (with some other library) or doing
-            # some other ugly hackery. Instead, the entire block of source and dest
-            # addresses for a given term is given a unique, computable name which
-            # is not related to the NETWORK.net token name.  that's what you get
-            # for using cisco, which has decided to implement its own meta language.
+        # I don't have an easy way get the token name used in the pol file
+        # w/o reading the pol file twice (with some other library) or doing
+        # some other ugly hackery. Instead, the entire block of source and dest
+        # addresses for a given term is given a unique, computable name which
+        # is not related to the NETWORK.net token name.  that's what you get
+        # for using cisco, which has decided to implement its own meta language.
 
-            # Create network object-groups
+        # Create network object-groups
         for name, ips in self.addressbook.addressbook[''].items():
-            for version in (4,6):
+            for version in (4, 6):
                 vips = [i for i in ips if i.version == version]
                 if vips:
 
@@ -322,7 +309,7 @@ class PortMap:
         110: 'pop3',
         1723: 'pptp',
         554: 'rtsp',
-        5060:'sip',
+        5060: 'sip',
         25: 'smtp',
         22: 'ssh',
         111: 'sunrpc',
@@ -333,6 +320,7 @@ class PortMap:
         43: 'whois',
         80: 'www',
     }
+
     _PORTS_UDP = {
         512: 'biff',
         68: 'bootpc',
@@ -350,7 +338,7 @@ class PortMap:
         123: 'ntp',
         496: 'pim-auto-rp',
         520: 'rip',
-        5060:'sip',
+        5060: 'sip',
         161: 'snmp',
         162: 'snmptrap',
         111: 'sunrpc',
@@ -362,6 +350,7 @@ class PortMap:
         513: 'who',
         177: 'xdmcp',
     }
+
     _TYPES_ICMP = {
         6: 'alternate-address',
         31: 'conversion-error',
@@ -399,6 +388,7 @@ class PortMap:
         1521: 'sqlnet',
     }
     _CISCO_PORTS_TCP.update(_PORTS_TCP)
+
     _CISCO_PORTS_UDP = {
         750: 'kerberos',
         5632: 'pcanywhere-status',
@@ -414,6 +404,7 @@ class PortMap:
         88: 'kerberos',
     }
     _ARISTA_PORTS_TCP.update(_PORTS_TCP)
+
     _ARISTA_PORTS_UDP = {
         88: 'kerberos',
         1812: 'radius',
@@ -495,15 +486,6 @@ class Term(aclgenerator.Term):
             self.text_af = 'inet6'
 
     def __str__(self):
-        # Verify platform specific terms. Skip whole term if platform does not
-        # match.
-        if self.term.platform:
-            if self.platform not in self.term.platform:
-                return ''
-        if self.term.platform_exclude:
-            if self.platform in self.term.platform_exclude:
-                return ''
-
         ret_str = ['\n']
 
         # Don't render icmpv6 protocol terms under inet, or icmp under inet6
@@ -861,15 +843,6 @@ class ObjectGroupTerm(Term):
         self.verbose = verbose
 
     def __str__(self):
-        # Verify platform specific terms. Skip whole term if platform does not
-        # match.
-        if self.term.platform:
-            if self.platform not in self.term.platform:
-                return ''
-        if self.term.platform_exclude:
-            if self.platform in self.term.platform_exclude:
-                return ''
-
         source_address_set = set()
         destination_address_set = set()
         ret_str = ['\n']
@@ -994,15 +967,10 @@ class Cisco(aclgenerator.ACLGenerator):
 
     def _TranslatePolicy(self, pol, exp_info):
         self.cisco_policies = []
-        current_date = datetime.datetime.utcnow().date()
-        exp_info_date = current_date + datetime.timedelta(weeks=exp_info)
-
         # a mixed filter outputs both ipv4 and ipv6 acls in the same output file
         good_filters = ['extended', 'standard', 'object-group', 'inet6', 'mixed', 'enable_dsmo']
 
         for header, terms in pol.filters:
-            if self._PLATFORM not in header.platforms:
-                continue
             obj_target = ObjectGroup()
 
             filter_options = header.FilterOptions(self._PLATFORM)
@@ -1065,22 +1033,6 @@ class Cisco(aclgenerator.ACLGenerator):
                     if term.restrict_address_family and term.restrict_address_family != af:
                         continue
 
-                    if term.expiration:
-                        if term.expiration <= exp_info_date:
-                            logging.info(
-                                'INFO: Term %s in policy %s expires ' 'in less than two weeks.',
-                                term.name,
-                                filter_name,
-                            )
-                        if term.expiration <= current_date:
-                            logging.warning(
-                                'WARNING: Term %s in policy %s is expired and '
-                                'will not be rendered.',
-                                term.name,
-                                filter_name,
-                            )
-                            continue
-
                     # render terms based on filter type
                     if next_filter == 'standard':
                         # keep track of sequence numbers across terms
