@@ -22,16 +22,14 @@ https://cloud.google.com/compute/docs/reference/latest/firewalls
 """
 
 import copy
-import datetime
 import ipaddress
 import json
-import logging
 import re
+from typing import Any, Dict
 
-from typing import Dict, Any
+from absl import logging
 
-from aerleon.lib import gcp
-from aerleon.lib import nacaddr
+from aerleon.lib import gcp, nacaddr
 
 
 class Error(gcp.Error):
@@ -446,13 +444,7 @@ class GCE(gcp.GCP):
         total_attribute_count = 0
         total_rule_count = 0
 
-        current_date = datetime.datetime.utcnow().date()
-        exp_info_date = current_date + datetime.timedelta(weeks=exp_info)
-
         for header, terms in pol.filters:
-            if self._PLATFORM not in header.platforms:
-                continue
-
             filter_options = header.FilterOptions(self._PLATFORM)
             filter_name = header.FilterName(self._PLATFORM)
 
@@ -484,6 +476,9 @@ class GCE(gcp.GCP):
             else:
                 logging.warning('GCE filter does not specify a network.')
 
+            if not terms:
+                continue
+
             term_names = set()
             if IsDefaultDeny(terms[-1]):
                 terms[-1].protocol = ['all']
@@ -524,32 +519,9 @@ class GCE(gcp.GCP):
                 term_names.add(term.name)
 
                 term.direction = direction
-                if term.expiration:
-                    if term.expiration <= exp_info_date:
-                        logging.info(
-                            'INFO: Term %s in policy %s expires ' 'in less than two weeks.',
-                            term.name,
-                            filter_name,
-                        )
-                    if term.expiration <= current_date:
-                        logging.warning(
-                            'WARNING: Term %s in policy %s is expired and '
-                            'will not be rendered.',
-                            term.name,
-                            filter_name,
-                        )
-                        continue
                 if term.option:
                     raise GceFirewallError('GCE firewall does not support term options.')
 
-                # Only generate the term if it's for the appropriate platform
-                if term.platform:
-                    if self._PLATFORM not in term.platform:
-                        continue
-                if term.platform_exclude:
-                    if self._PLATFORM in term.platform_exclude:
-                        continue
-
                 # Handle mixed for each indvidual term as inet and inet6.
                 # inet/inet6 are treated the same.
                 term_address_families = []
