@@ -7,12 +7,11 @@ Hierarchical Firewalls (HF) are represented in a SecurityPolicy GCP resouce.
 
 import copy
 import re
-
-from typing import Dict, Any
+from typing import Any, Dict
 
 from absl import logging
-from aerleon.lib import gcp
-from aerleon.lib import nacaddr
+
+from aerleon.lib import gcp, nacaddr
 
 
 class ExceededCostError(gcp.Error):
@@ -397,9 +396,6 @@ class HierarchicalFirewall(gcp.GCP):
         previous_max_cost = -1
         for header, terms in pol.filters:
 
-            if self._PLATFORM not in header.platforms:
-                continue
-
             filter_options = header.FilterOptions(self._PLATFORM)
 
             is_policy_modified = True
@@ -512,14 +508,6 @@ class HierarchicalFirewall(gcp.GCP):
                 term.name = self.FixTermLength(term.name)
                 term.direction = direction
 
-                # Only generate the term if it's for the appropriate platform
-                if term.platform:
-                    if self._PLATFORM not in term.platform:
-                        continue
-                if term.platform_exclude:
-                    if self._PLATFORM in term.platform_exclude:
-                        continue
-
                 for term_af in term_address_families:
                     rules = Term(
                         term,
