@@ -16,13 +16,12 @@
 
 """Iptables generator."""
 
-import datetime
 import re
 from string import Template  # pylint: disable=g-importing-member
 
 from absl import logging
-from aerleon.lib import aclgenerator
-from aerleon.lib import nacaddr
+
+from aerleon.lib import aclgenerator, nacaddr
 
 
 class Term(aclgenerator.Term):
@@ -105,15 +104,6 @@ class Term(aclgenerator.Term):
         self.term_name = '%s_%s' % (self.filter[:1], self.term.name)
 
     def __str__(self):
-        # Verify platform specific terms. Skip whole term if platform does not
-        # match.
-        if self.term.platform:
-            if self._PLATFORM not in self.term.platform:
-                return ''
-        if self.term.platform_exclude:
-            if self._PLATFORM in self.term.platform_exclude:
-                return ''
-
         ret_str = []
 
         # Don't render icmpv6 protocol terms under inet, or icmp under inet6
@@ -231,7 +221,7 @@ class Term(aclgenerator.Term):
         # icmp-types
         icmp_types = ['']
         if self.term.icmp_type:
-            
+
             icmp_types = self.NormalizeIcmpTypes(self.term.icmp_type, protocol, self.af)
 
         source_interface = ''
@@ -769,9 +759,6 @@ class Iptables(aclgenerator.ACLGenerator):
 
     def _TranslatePolicy(self, pol, exp_info):
         """Translate a policy from objects into strings."""
-        current_date = datetime.datetime.utcnow().date()
-        exp_info_date = current_date + datetime.timedelta(weeks=exp_info)
-
         default_action = None
         good_default_actions = ['ACCEPT', 'DROP']
         good_afs = ['inet', 'inet6']
@@ -780,9 +767,6 @@ class Iptables(aclgenerator.ACLGenerator):
 
         for header, terms in pol.filters:
             filter_type = None
-            if self._PLATFORM not in header.platforms:
-                continue
-
             self.filter_options = header.FilterOptions(self._PLATFORM)[1:]
             filter_name = header.FilterName(self._PLATFORM)
 
@@ -872,22 +856,6 @@ class Iptables(aclgenerator.ACLGenerator):
                 if not term:
                     continue
 
-                if term.expiration:
-                    if term.expiration <= exp_info_date:
-                        logging.info(
-                            'INFO: Term %s in policy %s expires ' 'in less than two weeks.',
-                            term.name,
-                            filter_name,
-                        )
-                    if term.expiration <= current_date:
-                        logging.warning(
-                            'WARNING: Term %s in policy %s is expired and '
-                            'will not be rendered.',
-                            term.name,
-                            filter_name,
-                        )
-                        continue
-
                 new_terms.append(
                     self._TERM(
                         term,
