@@ -15,12 +15,9 @@
 #
 """Juniper MS-MPC  generator for Aerleon."""
 
-import datetime
-import logging
+from absl import logging
 
-from aerleon.lib import aclgenerator
-from aerleon.lib import juniper
-from aerleon.lib import nacaddr
+from aerleon.lib import aclgenerator, juniper, nacaddr
 
 MAX_IDENTIFIER_LEN = 55  # It is really 63, but leaving room for added chars
 
@@ -36,6 +33,7 @@ class Term(juniper.Term):
 
     _PLATFORM = 'msmpc'
     _DEFAULT_INDENT = 20
+    _NO_APPLY_GROUPS_INDENT = 12
     _ACTIONS = {'accept': 'accept', 'deny': 'discard', 'reject': 'reject'}
     # msmpc supports a limited number of protocol names
     # https://www.juniper.net/documentation/us/en/software/junos/security-policies/topics/ref/statement/applications-edit-protocol.html
@@ -57,12 +55,13 @@ class Term(juniper.Term):
         'udp',
     )
 
-    def __init__(self, term, term_type, noverbose, filter_name):
+    def __init__(self, term, term_type, noverbose, filter_name, apply_groups):
         enable_dsmo = False
         super().__init__(term, term_type, enable_dsmo, noverbose)
         self.term = term
         self.term_type = term_type
         self.noverbose = noverbose
+        self.apply_groups = apply_groups
         self.filter_name = filter_name
 
         for prot in self.term.protocol:
@@ -71,19 +70,14 @@ class Term(juniper.Term):
                 self.term.protocol[loc] = str(self.PROTO_MAP.get(prot, prot))
 
     def __str__(self):
-        # Verify platform specific terms. Skip whole term if platform does not
-        # match.
-        if self.term.platform:
-            if self._PLATFORM not in self.term.platform:
-                return ''
-        if self.term.platform_exclude:
-            if self._PLATFORM in self.term.platform_exclude:
-                return ''
-
         if self.enable_dsmo:
             raise NotImplementedError('enable_dsmo not implemented for msmpc')
 
-        ret_str = juniper.Config(indent=self._DEFAULT_INDENT)
+        if self.apply_groups:
+            indent = self._DEFAULT_INDENT
+        else:
+            indent = self._NO_APPLY_GROUPS_INDENT
+        ret_str = juniper.Config(indent=indent)
 
         # COMMENTS
         # this deals just fine with multi line comments, but we could probably
@@ -509,20 +503,20 @@ class JuniperMSMPC(aclgenerator.ACLGenerator):
             return []
 
     def _TranslatePolicy(self, pol, exp_info):
-        current_date = datetime.date.today()
-        exp_info_date = current_date + datetime.timedelta(weeks=exp_info)
         self.junipermsmpc_policies = []
         for header, terms in pol.filters:
-            if self._PLATFORM not in header.platforms:
-                continue
             filter_options = header.FilterOptions(self._PLATFORM)
             filter_name = header.FilterName(self._PLATFORM)
             filter_options.remove(filter_name)
+            apply_groups = 'no-apply-groups' not in filter_options
             filter_direction = None
             filter_type = None
             noverbose = 'noverbose' in filter_options
             self.applications[filter_name] = []
 
+            if not apply_groups:
+                filter_options.remove('no-apply-groups')
+
             if noverbose:
                 # noverbose is a strict boolean, remove it
                 # prior to iterating through the other options
@@ -591,22 +585,7 @@ class JuniperMSMPC(aclgenerator.ACLGenerator):
                 if term.name in term_names:
                     raise JuniperMSMPCFilterError('Duplicate term name')
                 term_names.add(term.name)
-                if term.expiration:
-                    if term.expiration <= exp_info_date:
-                        logging.info(
-                            'INFO: Term %s in policy %s expires ' 'in less than two weeks.',
-                            term.name,
-                            filter_name,
-                        )
-                    if term.expiration <= current_date:
-                        logging.warning(
-                            'WARNING: Term %s in policy %s is expired and '
-                            'will not be rendered.',
-                            term.name,
-                            filter_name,
-                        )
-                        continue
-                new_term = Term(term, filter_type, noverbose, filter_name)
+                new_term = Term(term, filter_type, noverbose, filter_name, apply_groups)
                 new_terms.append(new_term)
 
                 # Because MSMPC terms can contain inet and inet6 addresses. We have to
@@ -662,7 +641,9 @@ class JuniperMSMPC(aclgenerator.ACLGenerator):
                     new_application_set['name'] = modified_term_name
                     self.applications[filter_name].append(new_application_set)
 
-            self.junipermsmpc_policies.append((header, filter_name, filter_direction, new_terms))
+            self.junipermsmpc_policies.append(
+                (header, filter_name, filter_direction, new_terms, apply_groups)
+            )
 
     def _Group(self, group, lc=True):
         """If 1 item return it, else return [ item1 item2 ].
@@ -709,9 +690,16 @@ class JuniperMSMPC(aclgenerator.ACLGenerator):
 
     def __str__(self):
         target = juniper.Config()
-        for (header, filter_name, filter_direction, terms) in self.junipermsmpc_policies:
-            target.Append('groups {')
-            target.Append('replace:')
+        for (
+            header,
+            filter_name,
+            filter_direction,
+            terms,
+            apply_groups,
+        ) in self.junipermsmpc_policies:
+            if apply_groups:
+                target.Append('groups {')
+                target.Append('replace:')
             target.Append('/*')
 
             # we want the acl to contain id and date tags, but p4 will expand
@@ -727,7 +715,8 @@ class JuniperMSMPC(aclgenerator.ACLGenerator):
                     target.Append('** ' + line)
             target.Append('*/')
 
-            target.Append('%s {' % filter_name)
+            if apply_groups:
+                target.Append('%s {' % filter_name)
             target.Append('services {')
             target.Append('stateful-firewall {')
             target.Append('rule %s {' % filter_name)
@@ -741,9 +730,10 @@ class JuniperMSMPC(aclgenerator.ACLGenerator):
             target.Append('}')  # services { ... }
             for line in self._GenerateApplications(filter_name):
                 target.Append(line)
-            target.Append('}')  # filter_name { ... }
-            target.Append('}')  # groups { ... }
-            target.Append('apply-groups %s;' % filter_name)
+            if apply_groups:
+                target.Append('}')  # filter_name { ... }
+                target.Append('}')  # groups { ... }
+                target.Append('apply-groups %s;' % filter_name)
         return str(target) + '\n'
 
 
