@@ -20,16 +20,13 @@
 
 import collections
 import copy
-import datetime
 import heapq
 import ipaddress
 import itertools
 
 from absl import logging
-from aerleon.lib import aclgenerator
-from aerleon.lib import nacaddr
-from aerleon.lib import addressbook
 
+from aerleon.lib import aclgenerator, addressbook, nacaddr
 
 ICMP_TERM_LIMIT = 8
 
@@ -363,13 +360,7 @@ class JuniperSRX(aclgenerator.ACLGenerator):
           ConflictingApplicationSetsError: When two duplicate named terms have
                                            conflicting application entries
         """
-        current_date = datetime.datetime.utcnow().date()
-        exp_info_date = current_date + datetime.timedelta(weeks=exp_info)
-
         for header, terms in pol.filters:
-            if self._PLATFORM not in header.platforms:
-                continue
-
             filter_options = header.FilterOptions(self._PLATFORM)
 
             verbose = True
@@ -477,14 +468,6 @@ class JuniperSRX(aclgenerator.ACLGenerator):
             new_terms = []
             self._FixLargePolices(terms, filter_type)
             for term in terms:
-                # Only generate the term if it's for the appropriate platform.
-                if term.platform:
-                    if self._PLATFORM not in term.platform:
-                        continue
-                if term.platform_exclude:
-                    if self._PLATFORM in term.platform_exclude:
-                        continue
-
                 if term.stateless_reply:
                     logging.warning(
                         "WARNING: Term %s in policy %s>%s is a stateless reply "
@@ -504,23 +487,6 @@ class JuniperSRX(aclgenerator.ACLGenerator):
                     raise SRXDuplicateTermError('You have a duplicate term: %s' % term.name)
                 term_dup_check.add(term.name)
 
-                if term.expiration:
-                    if term.expiration <= exp_info_date:
-                        logging.info(
-                            'INFO: Term %s in policy %s>%s expires ' 'in less than two weeks.',
-                            term.name,
-                            self.from_zone,
-                            self.to_zone,
-                        )
-                    if term.expiration <= current_date:
-                        logging.warning(
-                            'WARNING: Term %s in policy %s>%s is expired.',
-                            term.name,
-                            self.from_zone,
-                            self.to_zone,
-                        )
-                        continue
-
                 # SRX address books leverage network token names for IPs.
                 # When excluding addresses, we lose those distinct names so we need
                 # to create a new unique name based off the term name before excluding.
