@@ -17,11 +17,10 @@
 
 import collections
 import copy
-import datetime
-import logging
 
-from aerleon.lib import aclgenerator
-from aerleon.lib import nacaddr
+from absl import logging
+
+from aerleon.lib import aclgenerator, nacaddr
 
 # NFTables and Aerleon have conflicting definitions of 'address family'
 # In Aerleon:
@@ -549,12 +548,6 @@ class Term(aclgenerator.Term):
         Each term is expressed as its own chain. Later referenced to a parent chain
         with filter directionality (input/output).
         """
-        if self.term.platform:
-            if 'nftables' not in self.term.platform:
-                return ''
-        if self.term.platform_exclude:
-            if 'nftables' in self.term.platform_exclude:
-                return ''
         return ChainFormat('chain', self.term.name, self.RulesetGenerator(self.term))
 
 
@@ -642,11 +635,7 @@ class Nftables(aclgenerator.ACLGenerator):
 
         pol_counter = 0
 
-        current_date = datetime.date.today()
-        exp_info_date = current_date + datetime.timedelta(weeks=exp_info)
         for header, terms in pol.filters:
-            if self._PLATFORM not in header.platforms:
-                continue
             filter_options = header.FilterOptions('nftables')
             (
                 nf_af,
@@ -686,21 +675,6 @@ class Nftables(aclgenerator.ACLGenerator):
                         term.name,
                     )
                     continue
-                if term.expiration:
-                    if term.expiration <= exp_info_date:
-                        logging.info(
-                            'INFO: Term %s in policy %s expires ' 'in less than two weeks.',
-                            term.name,
-                            nf_af,
-                        )
-                    if term.expiration <= current_date:
-                        logging.warning(
-                            'WARNING: Term %s in policy %s is expired and '
-                            'will not be rendered.',
-                            term.name,
-                            nf_af,
-                        )
-                        continue
                 # Handle address excludes before building nft address book dict.
                 for i in term.source_address_exclude:
                     term.source_address = nacaddr.RemoveAddressFromList(term.source_address, i)
