@@ -18,12 +18,11 @@
 
 import collections
 import copy
-import datetime
 from typing import cast
 
 from absl import logging
-from aerleon.lib import aclgenerator
-from aerleon.lib import nacaddr
+
+from aerleon.lib import aclgenerator, nacaddr
 
 
 class Error(aclgenerator.Error):
@@ -115,15 +114,6 @@ class Term(aclgenerator.Term):
     def __str__(self):
         """Render config output from this term object."""
 
-        # Verify platform specific terms. Skip whole term if platform does not
-        # match.
-        if self.term.platform:
-            if self._PLATFORM not in self.term.platform:
-                return ''
-        if self.term.platform_exclude:
-            if self._PLATFORM in self.term.platform_exclude:
-                return ''
-
         ret_str = []
         self._SetDefaultAction()
 
@@ -458,18 +448,12 @@ class PacketFilter(aclgenerator.ACLGenerator):
         self.pf_policies = []
         self.address_book = {}
         self.def_short_to_long = {}
-        current_date = datetime.datetime.utcnow().date()
-        exp_info_date = current_date + datetime.timedelta(weeks=exp_info)
-
         good_afs = ['inet', 'inet6', 'mixed']
         good_options = ['in', 'out', 'nostate']
         all_protocols_stateful = True
 
         for header, terms in pol.filters:
             filter_type = None
-            if self._PLATFORM not in header.platforms:
-                continue
-
             filter_options = header.FilterOptions(self._PLATFORM)[1:]
             filter_name = header.FilterName(self._PLATFORM)
             direction = ''
@@ -576,22 +560,6 @@ class PacketFilter(aclgenerator.ACLGenerator):
                 if not term:
                     continue
 
-                if term.expiration:
-                    if term.expiration <= exp_info_date:
-                        logging.info(
-                            'INFO: Term %s in policy %s expires ' 'in less than two weeks.',
-                            term.name,
-                            filter_name,
-                        )
-                    if term.expiration <= current_date:
-                        logging.warning(
-                            'WARNING: Term %s in policy %s is expired and '
-                            'will not be rendered.',
-                            term.name,
-                            filter_name,
-                        )
-                        continue
-
                 if term.destination_interface and term.source_interface:
                     raise Error(
                         "packetfilter only supports destination interface XOR source interface per term"
