@@ -16,15 +16,13 @@
 
 import collections
 import copy
-import datetime
-import logging
 import re
-from xml.dom import minidom
 import xml.etree.ElementTree as etree
-from aerleon.lib import aclgenerator
-from aerleon.lib import addressbook
-from aerleon.lib import nacaddr
-from aerleon.lib import policy
+from xml.dom import minidom
+
+from absl import logging
+
+from aerleon.lib import aclgenerator, addressbook, nacaddr, policy
 
 
 class Error(aclgenerator.Error):
@@ -392,15 +390,10 @@ class PaloAltoFW(aclgenerator.ACLGenerator):
           PaloAltoFWUnsupportedProtocolError: The term contains unsupporter protocol
           name.
         """
-        current_date = datetime.date.today()
-        exp_info_date = current_date + datetime.timedelta(weeks=exp_info)
         first_addr_obj = None
         address_book_dup_check = set()
 
         for header, terms in pol.filters:
-            if self._PLATFORM not in header.platforms:
-                continue
-
             # The filter_options is a list of options from header, e.g.
             # ['from-zone', 'internal', 'to-zone', 'external']
             filter_options = header.FilterOptions(self._PLATFORM)
@@ -486,15 +479,6 @@ class PaloAltoFW(aclgenerator.ACLGenerator):
                     )
                     continue
 
-                # Verify platform specific terms. Skip whole term if platform does not
-                # match.
-                if term.platform:
-                    if self._PLATFORM not in term.platform:
-                        continue
-                if term.platform_exclude:
-                    if self._PLATFORM in term.platform_exclude:
-                        continue
-
                 if unique_term_prefixes:
                     # Prefix hash of from_zone and to_zone to the term name to get mostly
                     # unique names across different policies.
@@ -519,24 +503,6 @@ class PaloAltoFW(aclgenerator.ACLGenerator):
                         % (term.name, ', '.join(term.pan_application), ', '.join(term.protocol))
                     )
 
-                if term.expiration:
-                    if term.expiration <= exp_info_date:
-                        logging.info(
-                            "INFO: Term %s in policy %s>%s expires " "in less than two weeks.",
-                            term.name,
-                            self.from_zone,
-                            self.to_zone,
-                        )
-                    if term.expiration <= current_date:
-                        logging.warning(
-                            "WARNING: Term %s in policy %s>%s is expired and "
-                            "will not be rendered.",
-                            term.name,
-                            self.from_zone,
-                            self.to_zone,
-                        )
-                        continue
-
                 for i in term.source_address_exclude:
                     term.source_address = nacaddr.RemoveAddressFromList(term.source_address, i)
                 for i in term.destination_address_exclude:
@@ -889,7 +855,7 @@ class PaloAltoFW(aclgenerator.ACLGenerator):
         address_book_names_dict = {}
         address_book_groups_dict = {}
         try:
-          groups = sorted(self.addressbook.addressbook[''].keys())
+            groups = sorted(self.addressbook.addressbook[''].keys())
         except:
             groups = []
         for group in groups:
@@ -906,7 +872,7 @@ class PaloAltoFW(aclgenerator.ACLGenerator):
             # building individual address-group dictionary
             for nested_group in groups:
                 group_names = [i for i in address_book_names_dict.keys() if nested_group in i]
-                
+
                 address_book_groups_dict[nested_group] = group_names
 
         # sort address books and address sets
@@ -916,7 +882,7 @@ class PaloAltoFW(aclgenerator.ACLGenerator):
         address_book_keys = sorted(
             list(address_book_names_dict.keys()), key=self._SortAddressBookNumCheck
         )
-        
+
         # INITAL CONFIG
         config = etree.Element("config", {"urldb": "paloaltonetworks", "version": "8.1.0"})
         devices = etree.SubElement(config, "devices")
@@ -1173,7 +1139,7 @@ class PaloAltoFW(aclgenerator.ACLGenerator):
 
         vsys_entry.append(etree.Comment(" Addresses "))
         addr = etree.SubElement(vsys_entry, "address")
-        
+
         for name in address_book_keys:
             entry = etree.SubElement(addr, "entry", {"name": name})
             desc = etree.SubElement(entry, "description")
