@@ -28,9 +28,9 @@ having more confidence in it.
 Stolen liberally from packetfilter.py.
 """
 
-import datetime
 
 from absl import logging
+
 from aerleon.lib import aclgenerator
 
 
@@ -108,15 +108,6 @@ class Term(aclgenerator.Term):
 
     def __str__(self):
         """Render config output from this term object."""
-        # Verify platform specific terms. Skip whole term if platform does not
-        # match.
-        if self.term.platform:
-            if self._PLATFORM not in self.term.platform:
-                return ''
-        if self.term.platform_exclude:
-            if self._PLATFORM in self.term.platform_exclude:
-                return ''
-
         conditions = []
 
         # if terms does not specify action, use filter default action
@@ -374,18 +365,12 @@ class PcapFilter(aclgenerator.ACLGenerator):
 
     def _TranslatePolicy(self, pol, exp_info):
         self.pcap_policies = []
-        current_date = datetime.datetime.utcnow().date()
-        exp_info_date = current_date + datetime.timedelta(weeks=exp_info)
-
         good_afs = ['inet', 'inet6', 'mixed']
         good_options = ['in', 'out']
         direction = ''
 
         for header, terms in pol.filters:
             filter_type = None
-            if self._PLATFORM not in header.platforms:
-                continue
-
             filter_options = header.FilterOptions(self._PLATFORM)[1:]
             filter_name = header.FilterName(self._PLATFORM)
 
@@ -435,22 +420,6 @@ class PcapFilter(aclgenerator.ACLGenerator):
                         'You have a duplicate term: %s' % term.name
                     )
 
-                if term.expiration:
-                    if term.expiration <= exp_info_date:
-                        logging.info(
-                            'INFO: Term %s in policy %s expires ' 'in less than two weeks.',
-                            term.name,
-                            filter_name,
-                        )
-                    if term.expiration <= current_date:
-                        logging.warning(
-                            'WARNING: Term %s in policy %s is expired and '
-                            'will not be rendered.',
-                            term.name,
-                            filter_name,
-                        )
-                        continue
-
                 if not term:
                     continue
 
