@@ -20,15 +20,14 @@ from __future__ import annotations
 
 import datetime
 import os
+import pathlib
 import sys
 from typing import TYPE_CHECKING
 
 from absl import logging
-from ply import lex
-from ply import yacc
+from ply import lex, yacc
 
-from aerleon.lib import nacaddr
-from aerleon.lib import naming
+from aerleon.lib import nacaddr, naming
 
 if TYPE_CHECKING:
     from aerleon.lib.policy_builder import PolicyBuilder
@@ -70,6 +69,10 @@ class RecursionTooDeepError(Error):
     """Included files exceed maximum recursion depth."""
 
 
+class BadIncludePath(Error):
+    """Included file unable to load due to path restrictions."""
+
+
 class ParseError(Error):
     """ParseError in the input."""
 
@@ -1692,7 +1695,13 @@ class Header:
         for target in self.target:
             if target.platform == platform:
                 if target.options:
-                    return target.options[0]
+                    if platform in ['srx', 'paloalto']:
+                        if len(target.options) >= 3:
+                            return '%s>%s' % (target.options[1], target.options[3])
+                        else:
+                            return None
+                    else:
+                        return target.options[0]
         return None
 
     def __str__(self):
@@ -2661,7 +2670,19 @@ def _Preprocess(data, max_depth=5, base_dir=''):
         if len(words) > 1 and words[0] == '#include':
             # remove any quotes around included filename
             include_file = words[1].strip('\'"')
-            data = _ReadFile(os.path.join(base_dir, include_file))
+            include_path = os.path.join(base_dir, include_file)
+
+            if pathlib.Path(include_path).suffix != '.inc':
+                raise BadIncludePath(
+                    f"Include file name must end in \".inc\". File={include_path} base_directory={base_dir}"
+                )
+
+            if not _SubpathOf(base_dir, include_path):
+                raise BadIncludePath(
+                    f"Include file cannot be loaded from outside the base directory. File={include_path} base_directory={base_dir}"
+                )
+
+            data = _ReadFile(include_path)
             # recursively handle includes in included data
             inc_data = _Preprocess(data, max_depth - 1, base_dir=base_dir)
             rval.extend(inc_data)
@@ -2670,6 +2691,10 @@ def _Preprocess(data, max_depth=5, base_dir=''):
     return rval
 
 
+def _SubpathOf(parent, subpath):
+    return str(pathlib.Path(subpath).resolve()).startswith(str(pathlib.Path(parent).resolve()))
+
+
 def ParseFile(filename, definitions=None, optimize=True, base_dir='', shade_check=False):
     """Parse the policy contained in file, optionally provide a naming object.
 
